-- Table structure for table "rv_djax_bidder_request"

CREATE TABLE rv_djax_bidder_request (
  request_id SERIAL PRIMARY KEY,
  publisher_id INT NOT NULL,
  bidder_id VARCHAR(100) NOT NULL,
  impression INT NOT NULL,
  revenue INT NOT NULL,
  is_approved VARCHAR(1) CHECK (is_approved IN ('0', '1', '2')) NOT NULL,
  is_deleted SMALLINT NOT NULL DEFAULT 0,
  is_denied SMALLINT NOT NULL DEFAULT 0,
  is_admin_deleted INT NOT NULL,
  is_admin_denied INT NOT NULL,
  bidding_type VARCHAR(10) NOT NULL,
  vide INT NOT NULL,
  ad_format VARCHAR(50) NOT NULL,
  created_date TIMESTAMP NOT NULL,
  modified_date TIMESTAMP NOT NULL,
  description VARCHAR(255) NOT NULL,
  iab_size VARCHAR(100) NOT NULL
);

-- PostgreSQL automatically creates indexes for primary keys, so no need to add one separately.



-- Table structure for table "dj_hb_reports"

CREATE TABLE dj_hb_reports (
  datetime TIMESTAMP NOT NULL,
  zoneid INT NOT NULL,
  hb_bidder VARCHAR(200) NOT NULL,
  hb_source VARCHAR(20) NOT NULL,
  hb_media VARCHAR(20) NOT NULL,
  hb_size VARCHAR(20) NOT NULL,
  hb_wonbid DECIMAL(10,4) NOT NULL,
  impression INT NOT NULL,
  country VARCHAR(32) NOT NULL
);


ALTER TABLE dj_hb_reports ADD PRIMARY KEY (zoneid);

-- Table structure for table "dj_hb_tracking"

CREATE TABLE dj_hb_tracking (
  datetime TIMESTAMP NOT NULL,
  zoneid INT NOT NULL,
  hb_bidder VARCHAR(200) NOT NULL,
  hb_source VARCHAR(20) NOT NULL,
  hb_media VARCHAR(20) NOT NULL,
  hb_size VARCHAR(20) NOT NULL,
  hb_wonbid DECIMAL(10,4) NOT NULL,
  impression INT NOT NULL,
  country VARCHAR(32) NOT NULL
);


-- Table structure for table "rv_djax_thirdparty_invocation"


CREATE TABLE rv_djax_thirdparty_invocation (
  id BIGSERIAL PRIMARY KEY,
  affiliate_id INT NOT NULL,
  zone_id INT NOT NULL,
  bidder_detail TEXT NOT NULL,
  banner_type VARCHAR(10) NOT NULL,
  bidding_type INT NOT NULL DEFAULT 1, -- 1-clientside, 2-serverside
  bidders TEXT NOT NULL,
  bidder_id VARCHAR(255) NOT NULL,
  timeout INT NOT NULL,
  vid_details VARCHAR(255) NOT NULL,
  adunit VARCHAR(100) NOT NULL
);




-- Table structure for table "rv_hb_serverside_settings"


CREATE TABLE rv_hb_serverside_settings (
  id SERIAL PRIMARY KEY,
  account_id VARCHAR(255) NOT NULL,
  default_vendor VARCHAR(100) NOT NULL
);


-- Table structure for table "rv_hb_bidding_type_setting"

CREATE TABLE rv_hb_bidding_type_setting (
  id SERIAL PRIMARY KEY,
  bidding_type INT NOT NULL,
  s_accountid VARCHAR(255) NOT NULL,
  request_timeout INT NOT NULL
);



-- Table structure for table "rv_djax_hb_bidders_list"


CREATE TABLE rv_djax_hb_bidders_list (
  hb_bidder_id SERIAL PRIMARY KEY,
  hb_bidder_name VARCHAR(250) NOT NULL,
  hb_bidder_code VARCHAR(255) NOT NULL,
  module_name VARCHAR(255) NOT NULL,
  hb_ad_format VARCHAR(50) NOT NULL,
  dj_is_deleted SMALLINT NOT NULL DEFAULT 0, -- 0-active, 1-deleted
  dj_is_denied SMALLINT NOT NULL DEFAULT 0, -- 1-unblock, 0-blocked
  date_created TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  server_side VARCHAR(100) NOT NULL,
  dj_is_banner INT NOT NULL, -- 1-Yes, 2-No
  dj_is_video INT NOT NULL -- 1-Yes, 2-No
);


INSERT INTO rv_djax_hb_bidders_list (hb_bidder_id, hb_bidder_name, hb_bidder_code, module_name, hb_ad_format, dj_is_deleted, dj_is_denied, date_created, server_side, dj_is_banner, dj_is_video) VALUES
(1, '152Media', 'oftmedia', '', 'a:1:{i:0;s:1:\"1\";}', 1, 0, '2018-01-08 04:58:05', '', 1, 1),
(2, 'Aardvark', 'aardvark', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2021-01-20 16:16:05', '3', 1, 0),
(3, 'Adblade', 'adblade', '', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"2\";}', 0, 0, '2021-01-19 15:09:51', '3', 1, 1),
(4, 'AdBund', 'adbund', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 04:52:48', '', 1, 1),
(5, 'AdButler', 'adbutler', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2017-11-23 12:49:32', '', 1, 1),
(6, 'Adform', 'adform', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2021-01-19 08:52:35', '1', 1, 1),
(7, 'AdKernel', 'adkernel', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2021-01-19 08:52:52', '3', 1, 1),
(8, 'AdMedia', 'admedia', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 05:22:55', '', 1, 1),
(9, 'AdMixer', 'admixer', '', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"2\";}', 0, 0, '2018-01-08 05:23:52', '', 1, 1),
(10, 'AdSupply', 'adsupply', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 05:26:58', '', 1, 1),
(11, 'Adyoulike', 'adyoulike', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 05:47:54', '', 1, 1),
(12, 'AOL', 'aol', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:29:56', '', 1, 1),
(13, 'AppNexus AST', 'appnexusAst', '', 'a:3:{i:0;s:1:\"1\";i:1;s:1:\"2\";i:2;s:1:\"3\";}', 0, 0, '2017-11-22 05:24:42', '', 1, 1),
(14, 'AppNexus', 'appnexus', '', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"2\";}', 0, 0, '2021-01-21 12:16:05', '3', 1, 1),
(15, 'Atomx', 'atomx', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 05:47:45', '', 1, 1),
(16, 'Audience Network', 'audienceNetwork', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 05:48:26', '', 1, 1),
(17, 'Beachfront', 'beachfront', '', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"2\";}', 0, 0, '2018-01-08 05:49:16', '', 1, 1),
(18, 'Bidfluence', 'bidfluence', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 05:49:46', '', 1, 1),
(19, 'bRealTime', 'brealtime', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 05:50:10', '', 1, 1),
(20, 'Brightcom', 'brightcom', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 05:51:09', '', 1, 1),
(21, 'Conversant', 'conversant', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:14:33', '', 1, 1),
(22, 'Cox', 'cox', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:15:01', '', 1, 1),
(23, 'Defy Media', 'defymedia', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:16:27', '', 1, 1),
(24, 'DistrictM', 'districtm', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:16:54', '', 1, 1),
(25, 'DistrictmDMX', 'districtmDMX', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:17:13', '', 1, 1),
(26, 'E-Planning', 'eplanning', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:21:18', '', 1, 1),
(27, 'Feature Forward', 'featureforward', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:21:27', '', 1, 1),
(28, 'Fidelity Media', 'fidelity', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:21:09', '', 1, 1),
(29, 'GetIntent', 'getintent', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:22:13', '', 1, 1),
(30, 'GumGum', 'gumgum', '', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"3\";}', 0, 0, '2018-01-08 07:57:08', '', 1, 1),
(31, 'Head Bidding', 'headbidding', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:23:57', '', 1, 1),
(32, 'HIRO Media', 'hiromedia', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:24:10', '', 1, 1),
(33, 'Index Exchange (Casale)', 'indexExchange', '', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"2\";}', 0, 0, '2018-01-08 06:29:23', '', 1, 1),
(34, 'Inneractive', 'inneractive', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:47:43', '', 1, 1),
(35, 'Innity', 'innity', '', '0', 1, 0, '2018-01-08 06:47:43', '', 1, 1),
(36, 'J Carter Marketing', 'jcm', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:50:01', '', 1, 1),
(37, 'Kargo', 'kargo', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:51:00', '', 1, 1),
(38, 'Komoona', 'komoona', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:51:20', '', 1, 1),
(39, 'Krux Link', 'kruxlink', '', '0', 1, 0, '2018-01-08 06:47:43', '', 1, 1),
(40, 'Lifestreet', 'lifestreet', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:52:57', '', 1, 1),
(41, 'Mantis', 'mantis', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:53:18', '', 1, 1),
(42, 'Matomy', 'matomy', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:54:21', '', 1, 1),
(43, 'Meme Global', 'memeglobal', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:54:36', '', 1, 1),
(44, 'MobFox', 'mobfox', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:54:53', '', 1, 1),
(45, 'NginAd', 'nginad', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:55:15', '', 1, 1),
(46, 'OpenX', 'openx', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:59:18', '', 1, 1),
(47, 'Page Science', 'pagescience', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 07:01:45', '', 1, 1),
(48, 'Piximedia', 'piximedia', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 07:02:05', '', 1, 1),
(49, 'Pubmatic', 'pubmatic', '', '0', 1, 0, '2018-01-08 06:47:43', '', 1, 1),
(50, 'PulsePoint', 'pulsepoint', '', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"3\";}', 0, 0, '2018-01-08 07:56:55', '', 1, 1),
(51, 'Quantcast', 'quantcast', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:01:38', '', 1, 1),
(52, 'RhythmOne', 'rhythmone', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:02:54', '', 1, 1),
(53, 'Roxot', 'roxot', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:03:10', '', 1, 1),
(55, 'Sekindo', 'sekindoUM', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:05:09', '', 1, 1),
(56, 'Sharethrough', 'sharethrough', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:05:57', '', 1, 1),
(57, 'Smart AdServer', 'smartadserver', '', 'a:1:{i:0;s:1:\"1\";}', 1, 0, '2018-01-08 08:06:16', '', 1, 1),
(58, 'SmartyAds', 'smartyads', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:06:33', '', 1, 1),
(59, 'StickyAdsTV', 'stickyadstv', '', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"3\";}', 0, 0, '2018-01-08 08:09:12', '', 1, 1),
(60, 'Sonobi', 'sonobi', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:07:36', '', 1, 1),
(61, 'Sovrn', 'sovrn', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:07:50', '', 1, 1),
(62, 'Spotx', 'spotx', '', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"2\";}', 0, 0, '2019-09-16 19:27:23', '0', 1, 1),
(63, 'SpringServe', 'springserve', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:08:51', '', 1, 1),
(64, 'TapSense', 'tapsense', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:09:35', '', 1, 1),
(65, 'ThoughtLeadr', 'thoughtleadr', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:09:48', '', 1, 1),
(66, 'Trion Interactive', 'trion', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:14:34', '', 1, 1),
(67, 'TripleLift', 'triplelift', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:14:52', '', 1, 1),
(68, 'Twenga', 'twenga', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:16:02', '', 1, 1),
(69, 'ucfunnel', 'ucfunnel', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:16:20', '', 1, 1),
(70, 'Underdog Media', 'underdogmedia', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:16:55', '', 1, 1),
(71, 'Unruly', 'unruly', '', 'a:3:{i:0;s:1:\"1\";i:1;s:1:\"2\";i:2;s:1:\"3\";}', 0, 0, '2018-01-08 08:17:57', '', 1, 1),
(72, 'Vertamedia', 'vertamedia', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:18:18', '', 1, 1),
(73, 'Vertoz', 'vertoz', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:18:48', '', 1, 1),
(74, 'WideOrbit', 'wideorbit', '', 'a:1:{i:0;s:1:\"1\";}', 0, 1, '2018-01-08 08:19:07', '', 1, 1),
(75, 'Widespace', 'widespace', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:19:21', '', 1, 1),
(76, 'Xaxis', 'xhb', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:19:38', '', 1, 1),
(77, 'Yieldbot', 'yieldbot', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:20:12', '', 1, 1),
(80, 'ONE by AOL Display', 'onedisplay', '', '0', 0, 0, '2017-09-04 11:24:50', '', 1, 1),
(81, 'ONE by AOL Mobile', 'onemobile', '', '0', 0, 0, '2017-09-04 11:24:50', '', 1, 1),
(93, 'Innity', 'innity', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:47:58', '', 1, 1),
(99, 'Pubmatic', 'pubmatic', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2020-01-20 06:03:01', '0', 1, 1),
(100, 'Aol', 'aol', '', '0', 1, 0, '2017-09-06 11:42:25', '', 1, 1),
(106, 'bidder2', 'teat123', '', 'a:1:{i:0;s:1:\"1\";}', 1, 0, '2017-12-12 11:19:32', '', 1, 1),
(107, 'test', 'test', '', 'a:1:{i:0;s:1:\"1\";}', 1, 0, '2017-12-12 11:20:59', '', 1, 1),
(108, 'test1', 'test1', '', 'a:1:{i:0;s:1:\"1\";}', 1, 0, '2017-12-21 06:04:06', '', 1, 1),
(109, '33Across', '33across', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 05:08:31', '', 1, 1),
(110, 'A4g', 'a4g', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 05:14:41', '', 1, 1),
(111, 'AdOcean', 'adocean', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 05:25:24', '', 1, 1),
(112, 'AdSparc', 'adsparc', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 05:26:29', '', 1, 1),
(113, 'adxcg', 'adxcg', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 05:28:37', '', 1, 1),
(114, 'AerServ', 'aerserv', '', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"2\";}', 0, 0, '2018-01-08 05:48:08', '', 1, 1),
(115, 'Arteebee', 'arteebee', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 05:47:12', '', 1, 1),
(116, 'Bridgewell', 'bridgewell', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 05:50:53', '', 1, 1),
(117, 'C1X', 'c1x', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:10:46', '', 1, 1),
(118, 'Carambola', 'carambola', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:11:53', '', 1, 1),
(119, 'Centro Brand Exchange', 'centro', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:12:43', '', 1, 1),
(120, 'Colossus', 'colossusssp', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:13:09', '', 1, 1),
(121, 'ConnectAd', 'connectad', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:14:02', '', 1, 1),
(123, 'Essens', 'essens', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:18:49', '', 1, 1),
(124, 'Gourmet Ads', 'gourmetads', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:22:55', '', 1, 1),
(125, 'Huddled Masses', 'huddledmasses', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:24:45', '', 1, 1),
(126, 'imonomy', 'imonomy', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:25:28', '', 1, 1),
(127, 'Insticator', 'insticator', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:48:44', '', 1, 1),
(128, 'iQM', 'iqm', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:49:43', '', 1, 1),
(129, 'Justpremium', 'justpremium', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:50:42', '', 1, 1),
(130, 'Kumma', 'kumma', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:52:31', '', 1, 1),
(131, 'Marsmedia', 'marsmedia', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:54:00', '', 1, 1),
(132, 'ONE by AOL Display', 'onedisplay', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:56:29', '', 1, 1),
(133, '152 Media 2.0', 'onefiftytwo', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:57:12', '', 1, 1),
(134, 'ONE by AOL Mobile', 'onemobile', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 06:58:25', '', 1, 1),
(135, 'Optimatic', 'optimatic', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 07:00:10', '', 1, 1),
(136, 'Orbitsoft', 'orbitsoft', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 07:01:18', '', 1, 1),
(137, 'Platform.io', 'platformio', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 07:03:11', '', 1, 1),
(138, 'Pollux Network', 'pollux', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 07:53:47', '', 1, 1),
(139, 'Pubgears', 'pubgears', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 07:55:42', '', 1, 1),
(140, 'PulsePoint Lite', 'pulsepointLite', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:01:14', '', 1, 1),
(141, 'ReadPeak', 'readpeak', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:02:06', '', 1, 1),
(142, 'RealVu', 'realvu', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:02:42', '', 1, 1),
(143, 'Rtbdemand bidder', 'rtbdemand', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:03:48', '', 1, 1),
(144, 'Serverbid', 'serverbid', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:05:44', '', 1, 1),
(145, 'Somo Audience', 'somoaudience', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:07:11', '', 1, 1),
(146, 'Tremor', 'tremor', '', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"2\";}', 0, 0, '2018-01-08 08:13:20', '', 1, 1),
(147, 'TrustX', 'trustx', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:15:46', '', 1, 1),
(148, 'Undertone', 'undertone', '', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2018-01-08 08:17:27', '', 1, 1),
(149, 'Rubicon', 'rubicon', 'rubicon', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"2\";}', 0, 0, '2021-01-21 09:56:00', '3', 1, 1),
(150, 'djax', 'djax', 'djax', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"2\";}', 0, 0, '2019-10-29 06:01:55', '0', 1, 1),
(151, 'Wide name', 'wide', 'wide', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2020-01-29 08:30:44', '1', 1, 1),
(152, 'bidphysics', 'bidphysics', 'bidphysics', 'a:1:{i:0;s:1:\"1\";}', 0, 0, '2020-01-31 11:39:57', '0', 1, 1),
(153, 'test', 'test', 'test', 'a:3:{i:0;s:1:\"1\";i:1;s:1:\"2\";i:2;s:1:\"3\";}', 1, 0, '2020-02-29 06:50:21', '1', 1, 1),
(154, 'test1', 'test1', 'bidder', 'a:1:{i:0;s:1:\"1\";}', 1, 0, '2021-01-16 12:10:49', '1', 1, 1),
(155, 'test2', 'tes2', 'bidder', 'a:1:{i:0;s:1:\"1\";}', 1, 0, '2021-01-16 12:12:05', '2', 1, 1),
(156, 'test3', 'test3', 'bidder', 'a:1:{i:0;s:1:\"1\";}', 1, 0, '2021-01-16 12:15:50', '1', 1, 1),
(157, 'test4', 'test4', 'bidder', 'a:1:{i:0;s:1:\"1\";}', 1, 0, '2021-01-16 12:50:19', '2', 1, 1),
(159, 'Criteo', 'criteo', 'context', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"2\";}', 0, 0, '2021-01-19 18:12:03', '3', 1, 1),
(161, 'test123', 'test123', 'test123', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"2\";}', 1, 0, '2021-01-19 14:47:28', '3', 1, 1),
(162, 'test123', 'test123', 'test123', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"2\";}', 1, 0, '2021-01-20 12:59:04', '3', 1, 1),
(163, 'YahooSSP', 'yahoossp', 'YahooSSP', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"2\";}', 0, 0, '2022-03-07 03:45:02', '3', 1, 1),
(164, 'Smart Ad Server', 'smartx', 'Smart Ad Server', 'a:2:{i:0;s:1:\"1\";i:1;s:1:\"2\";}', 0, 0, '2022-03-07 03:55:41', '3', 1, 1);





-- Table structure for table "rv_djax_hb_params"


CREATE TABLE rv_djax_hb_params (
  hb_parameter_id SERIAL PRIMARY KEY,
  hb_parameter_name VARCHAR(250) NOT NULL,
  hb_bidder_id INT NOT NULL,
  required SMALLINT NOT NULL DEFAULT 0, -- 0-optional, 1-required
  dj_is_deleted SMALLINT NOT NULL DEFAULT 0, -- 0-active, 1-deleted
  dj_is_denied SMALLINT NOT NULL DEFAULT 0, -- 0-unblock, 1-block
  date_created TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  adunit_param SMALLINT NOT NULL -- Added after `required`
);




--
-- Dumping data for table `rv_djax_hb_params`
--

INSERT INTO rv_djax_hb_params (hb_parameter_id, hb_parameter_name, hb_bidder_id, required, adunit_param, dj_is_deleted, dj_is_denied, date_created) VALUES
(2, 'ai', 2, 1, 1, 0, 0, '2017-08-11 04:18:03'),
(3, 'sc', 2, 1, 1, 0, 0, '2017-08-11 04:18:03'),
(4, 'partnerId', 3, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(5, 'bidfloor', 3, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(6, 'sid', 4, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(7, 'bidfloor', 4, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(13, 'mid', 6, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(14, 'adxDomain', 6, 0, 0, 1, 0, '2017-08-11 04:18:03'),
(17, 'aid', 8, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(19, 'clientId', 10, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(20, 'siteId', 10, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(21, 'zoneId', 10, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(22, 'endpointUrl', 10, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(23, 'placement', 11, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(24, 'placement', 12, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(25, 'network', 12, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(26, 'alias', 12, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(27, 'server', 12, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(28, 'sizeId', 12, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(29, 'bidFloor', 12, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(42, 'id', 15, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(43, 'placementId', 16, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(44, 'format', 16, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(47, 'adunitId', 18, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(48, 'pubId', 18, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(49, 'reservePrice', 18, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(50, 'placementId', 19, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(53, 'site_id', 21, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(54, 'secure', 21, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(55, 'bidfloor', 21, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(56, 'tag_id', 21, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(57, 'position', 21, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(58, 'mimes', 21, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(59, 'maxduration', 21, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(60, 'api', 21, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(61, 'protocols', 21, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(62, 'size', 22, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(63, 'id', 22, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(64, 'siteId', 22, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(65, 'placementId', 23, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(66, 'placementId', 24, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(67, 'id', 25, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(68, 'floor', 25, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(69, 'revShare', 25, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(70, 'currency', 25, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(71, 'ci', 26, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(72, 'sv', 26, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(73, 'isv', 26, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(74, 't', 26, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(75, 'placementId', 27, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(76, 'zoneid', 28, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(77, 'loc', 28, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(78, 'click', 28, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(79, 'subid', 28, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(80, 'server', 28, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(81, 'pid', 29, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(82, 'tid', 29, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(83, 'cur', 29, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(84, 'floor', 29, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(85, 'video', 29, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(86, 'inScreen', 30, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(87, 'inSlot', 30, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(88, 'zoneId', 31, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(89, 'host', 31, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(90, 'accountId', 32, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(91, 'bidUrl', 32, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(92, 'id', 33, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(93, 'siteID', 33, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(94, 'tier2SiteID', 33, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(95, 'tier3SiteID', 33, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(96, 'appId', 34, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(97, 'adSpotType', 34, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(98, 'customParams', 34, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(99, 'pub', 35, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(100, 'zone', 35, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(101, 'id', 36, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(102, 'siteID', 36, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(103, 'tier2SiteID', 36, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(104, 'tier3SiteID', 36, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(105, 'placementId', 37, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(106, 'hbid', 38, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(107, 'placementId', 38, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(108, 'impid', 39, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(109, 'jstag_url', 40, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(110, 'slot', 40, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(111, 'adkey', 40, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(112, 'ad_size', 40, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(113, 'timeout', 40, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(114, 'property', 41, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(115, 'placementId', 42, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(116, 'tagid', 43, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(117, 's', 44, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(118, 'imp_instl', 44, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(119, 'pzoneid', 45, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(120, 'nginadDomain', 45, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(121, 'unit', 46, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(122, 'delDomain', 46, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(123, 'customParams', 46, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(124, 'placementId', 47, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(125, 'randomKey', 47, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(126, 'invCode', 47, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(127, 'member', 47, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(128, 'siteId', 48, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(129, 'placementId', 48, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(130, 'currency', 48, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(131, 'sizes', 48, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(132, 'publisherId', 49, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(133, 'adSlot', 49, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(134, 'cf', 50, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(135, 'cp', 50, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(136, 'ct', 50, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(137, 'publisherId', 51, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(138, 'battr', 51, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(139, 'placementId', 52, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(140, 'publisherId', 53, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(152, 'spaceId', 55, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(153, 'pkey', 56, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(154, 'domain', 57, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(155, 'siteId', 57, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(156, 'pageId', 57, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(157, 'formatId', 57, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(158, 'target', 57, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(159, 'currency', 57, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(160, 'bidfloor', 57, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(161, 'banner_id', 58, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(162, 'zoneId', 59, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(163, 'ad_unit', 60, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(164, 'dom_id', 60, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(165, 'floor', 60, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(166, 'tagid', 61, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(167, 'sizes', 61, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(168, 'channel_id', 62, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(169, 'video_slot', 62, 1, 0, 1, 0, '2017-08-11 04:18:03'),
(170, 'slot', 62, 1, 0, 1, 0, '2017-08-11 04:18:03'),
(181, 'impId', 63, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(182, 'supplyPartnerId', 63, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(183, 'ad_unit_id', 64, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(184, 'user', 64, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(185, 'refer', 64, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(186, 'lat', 64, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(187, 'long', 64, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(188, 'price_floor', 64, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(189, 'placementId', 65, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(190, 'pubId', 66, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(191, 'sectionId', 66, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(192, 're', 66, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(193, 'inventoryCode', 67, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(194, 'floor', 67, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(195, 'placementId', 68, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(196, 'siteId', 68, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(197, 'publisherId', 68, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(198, 'currency', 68, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(199, 'bidFloor', 68, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(200, 'country', 68, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(201, 'adid', 69, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(202, 'width', 69, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(203, 'height', 69, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(204, 'siteId', 70, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(205, 'siteId', 71, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(206, 'targetingUUID', 71, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(207, 'aid', 72, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(208, 'placementId', 72, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(209, 'placementId', 73, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(210, 'cpmFloor', 73, 0, 0, 0, 0, '2017-08-11 04:18:03'),
(211, 'pbId', 74, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(212, 'pId', 74, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(213, 'sid', 75, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(214, 'cur', 75, 1, 0, 0, 0, '2017-08-11 04:18:03'),
(218, 'aaaaaaa', 84, 1, 0, 1, 0, '2017-08-21 01:11:35'),
(219, 'accountID', 5, 1, 0, 0, 0, '2017-08-31 23:06:34'),
(220, 'zoneID', 5, 1, 0, 0, 0, '2017-08-31 23:06:34'),
(221, 'keyword', 5, 0, 0, 0, 0, '2017-08-31 23:06:34'),
(222, 'minCPM', 5, 0, 0, 0, 0, '2017-08-31 23:06:34'),
(223, 'maxCPM', 5, 0, 0, 0, 0, '2017-08-31 23:06:34'),
(224, 'param1', 85, 1, 0, 0, 0, '2017-09-01 01:40:18'),
(229, 'gfgf', 86, 1, 0, 0, 0, '2017-09-01 03:04:14'),
(230, 'ee', 86, 1, 0, 0, 0, '2017-09-01 03:04:14'),
(231, 'psn', 77, 1, 0, 0, 0, '2017-09-01 03:24:57'),
(232, 'slot', 77, 1, 0, 0, 0, '2017-09-01 03:24:57'),
(233, 'param1', 77, 0, 0, 0, 0, '2017-09-01 03:24:57'),
(236, 'param1', 87, 1, 0, 0, 0, '2017-09-03 23:14:42'),
(237, 'innity', 90, 1, 0, 0, 0, '2017-09-05 01:43:42'),
(239, 'innity', 92, 1, 0, 0, 0, '2017-09-05 01:49:40'),
(241, 'innity', 91, 1, 0, 0, 0, '2017-09-05 04:01:32'),
(242, 'pub', 93, 1, 0, 0, 0, '2017-11-21 23:11:01'),
(243, 'zone', 93, 1, 0, 0, 0, '2017-11-21 23:11:01'),
(244, 'param1', 94, 0, 0, 0, 0, '2017-09-05 23:11:16'),
(245, 'param2', 95, 0, 0, 0, 0, '2017-09-05 23:12:05'),
(246, 'param3', 96, 0, 0, 0, 0, '2017-09-05 23:12:37'),
(247, 'param1', 97, 0, 0, 0, 0, '2017-09-05 23:16:00'),
(248, 'param1', 98, 0, 0, 0, 0, '2017-09-05 23:16:56'),
(249, 'publisherId', 99, 1, 0, 0, 0, '2017-09-06 01:36:14'),
(250, 'adSlot', 99, 1, 0, 0, 0, '2017-09-06 01:36:14'),
(251, 'placement     ', 100, 1, 0, 0, 0, '2017-09-06 06:12:25'),
(252, 'networ', 100, 1, 0, 0, 0, '2017-09-06 06:12:25'),
(264, 'placementId', 76, 1, 0, 0, 0, '2017-11-21 03:08:04'),
(265, 'df', 76, 1, 0, 0, 0, '2017-11-21 03:08:04'),
(266, 'rr', 76, 0, 0, 0, 0, '2017-11-21 03:08:04'),
(267, 'placementId', 1, 1, 0, 0, 0, '2017-11-21 05:49:24'),
(268, 'para', 1, 1, 0, 0, 0, '2017-11-21 05:49:24'),
(381, 'param1', 101, 0, 0, 0, 0, '2017-11-21 06:57:19'),
(383, 'param1', 102, 1, 0, 0, 0, '2017-11-21 06:59:50'),
(385, 'test3', 104, 0, 0, 0, 0, '2017-11-21 07:02:28'),
(386, 'test2', 103, 1, 0, 0, 0, '2017-11-21 07:25:52'),
(387, 'host', 7, 1, 1, 0, 0, '2017-11-21 22:53:31'),
(388, 'zoneId', 7, 1, 0, 1, 0, '2017-11-21 22:53:31'),
(389, 'zone', 9, 1, 0, 0, 0, '2017-11-21 22:54:22'),
(390, 'placementId', 14, 1, 0, 0, 0, '2017-11-21 22:54:49'),
(402, 'appId', 17, 1, 0, 0, 0, '2017-11-21 22:55:54'),
(403, 'bidfloor', 17, 1, 0, 0, 0, '2017-11-21 22:55:54'),
(406, 'tagId', 20, 1, 0, 0, 0, '2017-11-21 23:11:19'),
(407, 'bidFloor', 20, 0, 0, 0, 0, '2017-11-21 23:11:19'),
(408, 'placementId', 13, 1, 0, 0, 0, '2017-11-21 23:54:42'),
(409, 'allowSmallerSizes', 13, 0, 0, 0, 0, '2017-11-21 23:54:42'),
(410, 'keywords', 13, 0, 0, 0, 0, '2017-11-21 23:54:42'),
(411, 'video', 13, 0, 0, 0, 0, '2017-11-21 23:54:42'),
(412, 'invCode', 13, 0, 0, 0, 0, '2017-11-21 23:54:42'),
(413, 'member', 13, 0, 0, 0, 0, '2017-11-21 23:54:42'),
(414, 'reserve', 13, 0, 0, 0, 0, '2017-11-21 23:54:42'),
(441, 'param1', 109, 0, 0, 0, 0, '2017-12-22 07:00:29'),
(442, 'test2', 101, 0, 0, 0, 0, '2017-12-22 07:58:41'),
(443, 'ad_unit', 62, 1, 0, 0, 0, '2019-09-10 10:31:46'),
(444, 'outstream_options', 62, 1, 0, 1, 0, '2019-09-10 10:31:46'),
(445, 'outstream_options', 62, 0, 0, 0, 0, '2019-09-10 11:19:58'),
(447, 'accountId', 0, 1, 0, 0, 0, '2019-10-23 10:34:26'),
(448, 'siteId', 0, 1, 0, 0, 0, '2019-10-23 10:34:26'),
(449, 'zoneId', 0, 1, 0, 0, 0, '2019-10-23 10:34:26'),
(450, 'video', 0, 1, 0, 0, 0, '2019-10-23 10:34:26'),
(451, 'accountId', 0, 1, 0, 0, 0, '2019-10-23 10:49:47'),
(452, 'siteId', 0, 1, 0, 0, 0, '2019-10-23 10:49:47'),
(453, 'zoneId', 0, 1, 0, 0, 0, '2019-10-23 10:49:47'),
(454, 'video', 0, 1, 0, 0, 0, '2019-10-23 10:49:47'),
(457, 'accountId', 0, 1, 0, 0, 0, '2019-10-23 11:55:31'),
(458, 'siteId', 0, 1, 0, 0, 0, '2019-10-23 11:55:31'),
(459, 'zoneId', 0, 1, 0, 0, 0, '2019-10-23 11:55:31'),
(460, 'video', 0, 1, 0, 0, 0, '2019-10-23 11:55:31'),
(461, 'accountId', 0, 1, 0, 0, 0, '2019-10-23 11:56:55'),
(462, 'siteId', 0, 1, 0, 0, 0, '2019-10-23 11:56:55'),
(463, 'zoneId', 0, 1, 0, 0, 0, '2019-10-23 11:56:55'),
(464, 'accountId', 149, 1, 0, 0, 0, '2019-10-23 11:59:57'),
(465, 'siteId', 149, 1, 0, 0, 0, '2019-10-23 11:59:57'),
(466, 'zoneId', 149, 1, 0, 0, 0, '2019-10-23 11:59:57'),
(467, 'video', 149, 1, 0, 1, 0, '2019-10-23 11:59:57'),
(468, 'publisherId', 150, 1, 0, 0, 0, '2019-10-29 06:01:41'),
(469, 'publisher', 151, 0, 0, 0, 0, '2020-01-29 08:30:44'),
(470, 'bidphysics', 152, 0, 0, 0, 0, '2020-01-31 11:38:40'),
(471, 'name', 153, 1, 0, 0, 0, '2020-02-29 06:50:21'),
(472, 'name2', 153, 0, 0, 0, 0, '2020-02-29 06:50:21'),
(473, 'Test', 2, 1, 1, 0, 0, '2021-01-15 17:51:43'),
(474, 'end', 6, 0, 0, 0, 0, '2021-01-15 19:10:11'),
(475, 'test', 154, 0, 0, 0, 0, '2021-01-16 11:41:11'),
(476, 'test_param', 155, 0, 0, 0, 0, '2021-01-16 12:12:05'),
(477, 'test_param', 156, 0, 0, 0, 0, '2021-01-16 12:15:50'),
(478, 'test', 157, 0, 0, 0, 0, '2021-01-16 12:50:07'),
(479, 'zoneId', 158, 1, 0, 0, 0, '2021-01-16 13:06:04'),
(480, 'networkId', 158, 1, 0, 0, 0, '2021-01-16 13:06:04'),
(481, 'zoneId', 159, 1, 0, 0, 0, '2021-01-16 13:10:11'),
(482, 'networkId', 159, 1, 0, 0, 0, '2021-01-16 13:10:11'),
(483, 'nativeCallback', 159, 0, 0, 0, 0, '2021-01-16 13:10:11'),
(484, 'integrationMode', 159, 0, 0, 0, 0, '2021-01-16 13:10:11'),
(485, 'zoneId', 160, 1, 0, 0, 0, '2021-01-19 14:43:56'),
(486, 'zoneId', 161, 1, 0, 0, 0, '2021-01-19 14:47:28'),
(487, 'zoneId', 162, 1, 0, 0, 0, '2021-01-20 12:59:04'),
(488, 'siteId', 163, 1, 0, 0, 0, '2022-03-07 03:45:02'),
(489, 'pubId', 163, 1, 0, 0, 0, '2022-03-07 03:45:02'),
(490, 'placementId', 163, 1, 0, 0, 0, '2022-03-07 03:45:02'),
(491, 'tagId', 164, 1, 0, 0, 0, '2022-03-07 03:55:41'),
(492, 'publisherId', 164, 1, 0, 0, 0, '2022-03-07 03:55:41'),
(493, 'siteId', 164, 1, 0, 0, 0, '2022-03-07 03:55:41'),
(494, 'bidfloor', 164, 0, 0, 0, 0, '2022-03-07 03:55:41'),
(495, 'bidfloorcur', 164, 0, 0, 0, 0, '2022-03-07 03:55:41'),
(496, 'at', 164, 0, 0, 0, 0, '2022-03-07 03:55:41'),
(497, 'OneTag', 165, 1, 1, 0, 0, '2024-12-24 14:48:30'),
(498, 'OneTag', 166, 1, 0, 0, 0, '2024-12-24 14:56:37'),
(499, 'pubId', 167, 1, 0, 0, 0, '2024-12-24 14:59:08'),
(500, 'id', 168, 1, 0, 0, 0, '2025-01-27 13:32:06'),
(501, 'accountID', 169, 1, 0, 0, 0, '2025-01-27 13:32:42'),
(502, 'publisher', 170, 1, 0, 0, 0, '2025-01-27 13:33:19'),
(503, 'q', 171, 1, 0, 0, 0, '2025-01-28 11:22:27'),
(504, 'q', 172, 1, 0, 0, 0, '2025-01-28 18:06:20'),
(505, 'dsds', 173, 1, 0, 0, 0, '2025-01-30 11:04:14'),
(506, 'zoneId', 7, 1, 0, 0, 0, '2025-02-11 14:30:24'),
(507, 'host', 174, 1, 0, 0, 0, '2025-02-11 14:35:23'),
(508, 'zoneId', 174, 1, 0, 0, 0, '2025-02-11 14:35:23');




CREATE TABLE rv_djax_hb_param_value (
  hb_parameter_value_id SERIAL PRIMARY KEY,
  account_id INT NOT NULL,
  hb_bidder_id INT NOT NULL,
  request_id INT NOT NULL,
  parameter_id INT NOT NULL,
  param_value VARCHAR(100) NOT NULL,
  dj_admin_approve VARCHAR(1) NOT NULL CHECK (dj_admin_approve IN ('0', '1', '2')), -- '0'-Rejected, '1'-approved, '2'-Awaiting
  dj_is_param_deleted INT NOT NULL DEFAULT 0,
  dj_is_param_denied INT NOT NULL DEFAULT 0,
  dj_date_time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  updated_date TIMESTAMP NOT NULL,
  dj_is_deleted INT NOT NULL,
  dj_is_denied INT NOT NULL,
  ad_element_id SMALLINT NOT NULL -- Added after `dj_is_denied`
);



-- Table structure for table "rv_djax_hb_sub_param"

CREATE TABLE rv_djax_hb_sub_param (
  hb_sub_parameter_id SERIAL PRIMARY KEY,  -- Auto-incremented ID, using SERIAL
  hb_sub_parameter_name VARCHAR(250) NOT NULL,
  hb_parameter_id INT NOT NULL,  -- Replaced mediumint(9) with INT
  hb_bidder_id INT NOT NULL,  -- Replaced mediumint(9) with INT
  required SMALLINT NOT NULL DEFAULT 0 CHECK (required IN (0, 1)),  -- 0-optional, 1-required
  dj_is_deleted SMALLINT NOT NULL DEFAULT 0 CHECK (dj_is_deleted IN (0, 1)),  -- 0-active, 1-deleted
  dj_is_denied SMALLINT NOT NULL DEFAULT 0 CHECK (dj_is_denied IN (0, 1)),  -- 0-unblock, 1-block
  date_created TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP
);

-- Primary key already specified in the CREATE TABLE statement
-- No need for an ALTER TABLE for primary key in PostgreSQL

-- There is no need to separately define AUTO_INCREMENT as SERIAL automatically handles it for PostgreSQL



CREATE TABLE rv_djax_hb_sub_param_value (
  hb_parameter_sub_value_id SERIAL PRIMARY KEY,  -- Auto-incremented ID, using SERIAL
  account_id INT NOT NULL,  -- Replaced mediumint(9) with INT
  hb_bidder_id INT NOT NULL,  -- Replaced mediumint(9) with INT
  parameter_id INT NOT NULL,  -- Replaced mediumint(9) with INT
  sub_para_id INT DEFAULT NULL,  -- Replaced mediumint(9) with INT
  sub_param_value VARCHAR(50) DEFAULT NULL,
  dj_admin_approve SMALLINT NOT NULL DEFAULT 0 CHECK (dj_admin_approve IN (0, 1)),  -- 0-not, 1-approved
  dj_is_subparam_deleted INT NOT NULL DEFAULT 0,
  dj_is_subparam_denied INT NOT NULL DEFAULT 0,
  dj_date_time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  updated_date TIMESTAMP NOT NULL,  -- Changed to TIMESTAMP, as `datetime` is not a PostgreSQL type
  request_id INT NOT NULL
);



CREATE TABLE banner_vast_element_seq (
  id SERIAL PRIMARY KEY  -- AUTO_INCREMENT functionality handled by SERIAL
);


-- Table structure for table "djaxbanner_vast_element_seq"

CREATE TABLE djaxbanner_vast_element_seq (
  id SERIAL PRIMARY KEY  -- AUTO_INCREMENT functionality handled by SERIAL
);



-- Table structure for table "djax_site_categories"

CREATE TABLE djax_site_categories (
  category_id SERIAL PRIMARY KEY,  -- Using SERIAL for auto-increment
  category_name VARCHAR(50) NOT NULL,
  value VARCHAR(10) NOT NULL,
  description TEXT NOT NULL,
  parent_category_id VARCHAR(10) NOT NULL DEFAULT '0',
  is_deleted INT NOT NULL DEFAULT 0,  -- Converted TINYINT to INT
  is_blocked INT NOT NULL DEFAULT 0   -- Converted TINYINT to INT
);

-- In PostgreSQL, `SERIAL` handles auto-incrementing, so no need for a separate `ALTER TABLE` command.
-- The `PRIMARY KEY` constraint is already added by defining the column as `SERIAL`.





INSERT INTO djax_site_categories (category_id, category_name, value, description, parent_category_id, is_deleted, is_blocked) VALUES
(1, 'Arts & Entertainment', 'IAB1', '', '0', 0, 0),
(2, 'Books & Literature', 'IAB1-1', '', 'IAB1', 0, 0),
(4, 'Celebrity Fan/Gossip', 'IAB1-2', '', 'IAB1', 0, 0),
(5, 'Fine Art', 'IAB1-3', '', 'IAB1', 0, 0),
(6, 'Humor', 'IAB1-4', '', 'IAB1', 0, 0),
(7, 'Movies', 'IAB1-5', '', 'IAB1', 0, 0),
(8, 'Music', 'IAB1-6', '', 'IAB1', 0, 0),
(9, 'Television', 'IAB1-7', '', 'IAB1', 0, 0),
(10, 'Automotive', 'IAB2', '', '0', 0, 0),
(11, 'Auto Parts', 'IAB2-1', '', 'IAB2', 0, 0),
(12, 'Auto Repair', 'IAB2-2', '', 'IAB2', 0, 0),
(13, 'Buying/Selling Cars', 'IAB2-3', '', 'IAB2', 0, 0),
(14, 'Car Culture', 'IAB2-4', '', 'IAB2', 0, 0),
(15, 'Certified Pre-Owned', 'IAB2-5', '', 'IAB2', 0, 0),
(16, 'Convertible', 'IAB2-6', '', 'IAB2', 0, 0),
(17, 'Coupe', 'IAB2-7', '', 'IAB2', 0, 0),
(18, 'Crossover', 'IAB2-8', '', 'IAB2', 0, 0),
(19, 'Diesel', 'IAB2-9', '', 'IAB2', 0, 0),
(20, 'Electric Vehicle', 'IAB2-10', '', 'IAB2', 0, 0),
(21, 'Hatchback', 'IAB2-11', '', 'IAB2', 0, 0),
(22, 'Hybrid', 'IAB2-12', '', 'IAB2', 0, 0),
(23, 'Luxury', 'IAB2-13', '', 'IAB2', 0, 0),
(24, 'MiniVan', 'IAB2-14', '', 'IAB2', 0, 0),
(25, 'Motorcycles', 'IAB2-15', '', 'IAB2', 0, 0),
(26, 'Off-Road Vehicles', 'IAB2-16', '', 'IAB2', 0, 0),
(27, 'Performance Vehicles', 'IAB2-17', '', 'IAB2', 0, 0),
(28, 'Pickup', 'IAB2-18', '', 'IAB2', 0, 0),
(29, 'Road-Side Assistance', 'IAB2-19', '', 'IAB2', 0, 0),
(30, 'Sedan', 'IAB2-20', '', 'IAB2', 0, 0),
(31, 'Trucks & Accessories', 'IAB2-21', '', 'IAB2', 0, 0),
(32, 'Vintage Cars', 'IAB2-22', '', 'IAB2', 0, 0),
(33, 'Wagon', 'IAB2-23', '', 'IAB2', 0, 0),
(34, 'Business', 'IAB3', '', '0', 0, 0),
(35, 'Advertising', 'IAB3-1', '', 'IAB3', 0, 0),
(36, 'Agriculture', 'IAB3-2', '', 'IAB3', 0, 0),
(37, 'Biotech/Biomedical', 'IAB3-3', '', 'IAB3', 0, 0),
(38, 'Business Software', 'IAB3-4', '', 'IAB3', 0, 0),
(39, 'Construction', 'IAB3-5', '', 'IAB3', 0, 0),
(40, 'Forestry', 'IAB3-6', '', 'IAB3', 0, 0),
(41, 'Government', 'IAB3-7', '', 'IAB3', 0, 0),
(42, 'Green Solutions', 'IAB3-8', '', 'IAB3', 0, 0),
(43, 'Human Resources', 'IAB3-9', '', 'IAB3', 0, 0),
(44, 'Logistics', 'IAB3-10', '', 'IAB3', 0, 0),
(45, 'Marketing', 'IAB3-11', '', 'IAB3', 0, 0),
(46, 'Metals', 'IAB3-12', '', 'IAB3', 0, 0),
(47, 'Careers', 'IAB4', '', '0', 0, 0),
(48, 'Career Planning', 'IAB4-1', '', 'IAB4', 0, 0),
(49, 'College', 'IAB4-2', '', 'IAB4', 0, 0),
(50, 'Financial Aid', 'IAB4-3', '', 'IAB4', 0, 0),
(51, 'Job Fairs', 'IAB4-4', '', 'IAB4', 0, 0),
(52, 'Job Search', 'IAB4-5', '', 'IAB4', 0, 0),
(53, 'Resume Writing/Advice', 'IAB4-6', '', 'IAB4', 0, 0),
(54, 'Nursing', 'IAB4-7', '', 'IAB4', 0, 0),
(55, 'Scholarships', 'IAB4-8', '', 'IAB4', 0, 0),
(56, 'Telecommuting', 'IAB4-9', '', 'IAB4', 0, 0),
(57, 'U.S. Military', 'IAB4-10', '', 'IAB4', 0, 0),
(58, 'Career Advice', 'IAB4-11', '', 'IAB4', 0, 0),
(59, 'Education', 'IAB5', '', '0', 0, 0),
(60, '7-12 Education', 'IAB5-1', '', 'IAB5', 0, 0),
(61, 'Adult Education', 'IAB5-2', '', 'IAB5', 0, 0),
(62, 'Art History', 'IAB5-3', '', 'IAB5', 0, 0),
(63, 'Colledge Administration', 'IAB5-4', '', 'IAB5', 0, 0),
(64, 'College Life', 'IAB5-5', '', 'IAB5', 0, 0),
(65, 'Distance Learning', 'IAB5-6', '', 'IAB5', 0, 0),
(66, 'English as a 2nd Language', 'IAB5-7', '', 'IAB5', 0, 0),
(67, 'Language Learning', 'IAB5-8', '', 'IAB5', 0, 0),
(68, 'Graduate School', 'IAB5-9', '', 'IAB5', 0, 0),
(69, 'Homeschooling', 'IAB5-10', '', 'IAB5', 0, 0),
(70, 'Homework/Study Tips', 'IAB5-11', '', 'IAB5', 0, 0),
(71, 'K-6 Educators', 'IAB5-12', '', 'IAB5', 0, 0),
(72, 'Private School', 'IAB5-13', '', 'IAB5', 0, 0),
(73, 'Special Education', 'IAB5-14', '', 'IAB5', 0, 0),
(74, 'Studying Business', 'IAB5-15', '', 'IAB5', 0, 0),
(75, 'Family & Parenting', 'IAB6', '', '0', 0, 0),
(76, 'Adoption', 'IAB6-1', '', 'IAB6', 0, 0),
(77, 'Babies & Toddlers', 'IAB6-2', '', 'IAB6', 0, 0),
(78, 'Daycare/Pre School', 'IAB6-3', '', 'IAB6', 0, 0),
(79, 'Family Internet', 'IAB6-4', '', 'IAB6', 0, 0),
(80, 'Parenting - K-6 Kids', 'IAB6-5', '', 'IAB6', 0, 0),
(81, 'Parenting teens', 'IAB6-6', '', 'IAB6', 0, 0),
(82, 'Pregnancy', 'IAB6-7', '', 'IAB6', 0, 0),
(83, 'Special Needs Kids', 'IAB6-8', '', 'IAB6', 0, 0),
(84, 'Eldercare', 'IAB6-9', '', 'IAB6', 0, 0),
(85, 'Health & Fitness', 'IAB7', '', '0', 0, 0),
(86, 'Exercise', 'IAB7-1', '', 'IAB7', 0, 0),
(87, 'A.D.D.', 'IAB7-2', '', 'IAB7', 0, 0),
(88, 'AIDS/HIV', 'IAB7-3', '', 'IAB7', 0, 0),
(89, 'Allergies', 'IAB7-4', '', 'IAB7', 0, 0),
(90, 'Alternative Medicine', 'IAB7-5', '', 'IAB7', 0, 0),
(91, 'Arthritis', 'IAB7-6', '', 'IAB7', 0, 0),
(92, 'Asthma', 'IAB7-7', '', 'IAB7', 0, 0),
(93, 'Autism/PDD', 'IAB7-8', '', 'IAB7', 0, 0),
(94, 'Bipolar Disorder', 'IAB7-9', '', 'IAB7', 0, 0),
(95, 'Brain Tumor', 'IAB7-10', '', 'IAB7', 0, 0),
(96, 'Cancer', 'IAB7-11', '', 'IAB7', 0, 0),
(97, 'Cholesterol', 'IAB7-12', '', 'IAB7', 0, 0),
(98, 'Chronic Fatigue Syndrome', 'IAB7-13', '', 'IAB7', 0, 0),
(99, 'Chronic Pain', 'IAB7-14', '', 'IAB7', 0, 0),
(100, 'Cold & Flu', 'IAB7-15', '', 'IAB7', 0, 0),
(101, 'Deafness', 'IAB7-16', '', 'IAB7', 0, 0),
(102, 'Dental Care', 'IAB7-17', '', 'IAB7', 0, 0),
(103, 'Depression', 'IAB7-18', '', 'IAB7', 0, 0),
(104, 'Dermatology', 'IAB7-19', '', 'IAB7', 0, 0),
(105, 'Diabetes', 'IAB7-20', '', 'IAB7', 0, 0),
(106, 'Epilepsy', 'IAB7-21', '', 'IAB7', 0, 0),
(107, 'GERD/Acid Reflux', 'IAB7-22', '', 'IAB7', 0, 0),
(108, 'Headaches/Migraines', 'IAB7-23', '', 'IAB7', 0, 0),
(109, 'Heart Disease', 'IAB7-24', '', 'IAB7', 0, 0),
(110, 'Herbs for Health', 'IAB7-25', '', 'IAB7', 0, 0),
(111, 'Holistic Healing', 'IAB7-26', '', 'IAB7', 0, 0),
(112, 'IBS/Crohn\s Disease', 'IAB7-27', '', 'IAB7', 0, 0),
(113, 'Incest/Abuse Support', 'IAB7-28', '', 'IAB7', 0, 0),
(114, 'Incontinence', 'IAB7-29', '', 'IAB7', 0, 0),
(115, 'Infertility', 'IAB7-30', '', 'IAB7', 0, 0),
(116, 'Men\s Health', 'IAB7-31', '', 'IAB7', 0, 0),
(117, 'Nutrition', 'IAB7-32', '', 'IAB7', 0, 0),
(118, 'Orthopedics', 'IAB7-33', '', 'IAB7', 0, 0),
(119, 'Panic/Anxiety Disorders', 'IAB7-34', '', 'IAB7', 0, 0),
(120, 'Pediatrics', 'IAB7-35', '', 'IAB7', 0, 0),
(121, 'Physical Therapy', 'IAB7-36', '', 'IAB7', 0, 0),
(122, 'Psychology/Psychiatry', 'IAB7-37', '', 'IAB7', 0, 0),
(123, 'Senor Health', 'IAB7-38', '', 'IAB7', 0, 0),
(124, 'Sexuality', 'IAB7-39', '', 'IAB7', 0, 0),
(125, 'Sleep Disorders', 'IAB7-40', '', 'IAB7', 0, 0),
(126, 'Smoking Cessation', 'IAB7-41', '', 'IAB7', 0, 0),
(127, 'Substance Abuse', 'IAB7-42', '', 'IAB7', 0, 0),
(128, 'Thyroid Disease', 'IAB7-43', '', 'IAB7', 0, 0),
(129, 'Weight Loss', 'IAB7-44', '', 'IAB7', 0, 0),
(130, 'Women\s Health', 'IAB7-45', '', 'IAB7', 0, 0),
(131, 'Food & Drink', 'IAB8', '', '0', 0, 0),
(132, 'American Cuisine', 'IAB8-1', '', 'IAB8', 0, 0),
(133, 'Barbecues & Grilling', 'IAB8-2', '', 'IAB8', 0, 0),
(134, 'Cajun/Creole', 'IAB8-3', '', 'IAB8', 0, 0),
(135, 'Chinese Cuisine', 'IAB8-4', '', 'IAB8', 0, 0),
(136, 'Cocktails/Beer', 'IAB8-5', '', 'IAB8', 0, 0),
(137, 'Coffee/Tea', 'IAB8-6', '', 'IAB8', 0, 0),
(138, 'Cuisine-Specific', 'IAB8-7', '', 'IAB8', 0, 0),
(139, 'Desserts & Baking', 'IAB8-8', '', 'IAB8', 0, 0),
(140, 'Dining Out', 'IAB8-9', '', 'IAB8', 0, 0),
(141, 'Food Allergies', 'IAB8-10', '', 'IAB8', 0, 0),
(142, 'French Cuisine', 'IAB8-11', '', 'IAB8', 0, 0),
(143, 'Health/Lowfat Cooking', 'IAB8-12', '', 'IAB8', 0, 0),
(144, 'Italian Cuisine', 'IAB8-13', '', 'IAB8', 0, 0),
(145, 'Japanese Cuisine', 'IAB8-14', '', 'IAB8', 0, 0),
(146, 'Mexican Cuisine', 'IAB8-15', '', 'IAB8', 0, 0),
(147, 'Vegan', 'IAB8-16', '', 'IAB8', 0, 0),
(148, 'Vegetarian', 'IAB8-17', '', 'IAB8', 0, 0),
(149, 'Wine', 'IAB8-18', '', 'IAB8', 0, 0),
(151, 'Hobbies & Interests', 'IAB9', '', '0', 0, 0),
(152, 'Art/Technology', 'IAB9-1', '', 'IAB9', 0, 0),
(153, 'Arts & Crafts', 'IAB9-2', '', 'IAB9', 0, 0),
(154, 'Beadwork', 'IAB9-3', '', 'IAB9', 0, 0),
(155, 'Birdwatching', 'IAB9-4', '', 'IAB9', 0, 0),
(156, 'Board Games/Puzzles', 'IAB9-5', '', 'IAB9', 0, 0),
(157, 'Candle & Soap Making', 'IAB9-6', '', 'IAB9', 0, 0),
(158, 'Card Games', 'IAB9-7', '', 'IAB9', 0, 0),
(159, 'Chess', 'IAB9-8', '', 'IAB9', 0, 0),
(160, 'Cigars', 'IAB9-9', '', 'IAB9', 0, 0),
(161, 'Collecting', 'IAB9-10', '', 'IAB9', 0, 0),
(162, 'Comic Books', 'IAB9-11', '', 'IAB9', 0, 0),
(163, 'Drawing/Sketching', 'IAB9-12', '', 'IAB9', 0, 0),
(164, 'Freelance Writing', 'IAB9-13', '', 'IAB9', 0, 0),
(165, 'Genealogy', 'IAB9-14', '', 'IAB9', 0, 0),
(166, 'Getting Published', 'IAB9-15', '', 'IAB9', 0, 0),
(167, 'Guitar', 'IAB9-16', '', 'IAB9', 0, 0),
(168, 'Home Recording', 'IAB9-17', '', 'IAB9', 0, 0),
(169, 'Investors & Patents', 'IAB9-18', '', 'IAB9', 0, 0),
(170, 'Jewelry Making', 'IAB9-19', '', 'IAB9', 0, 0),
(171, 'Magic & Illusion', 'IAB9-20', '', 'IAB9', 0, 0),
(172, 'Needlework', 'IAB9-21', '', 'IAB9', 0, 0),
(173, 'Painting', 'IAB9-22', '', 'IAB9', 0, 0),
(174, 'Photography', 'IAB9-23', '', 'IAB9', 0, 0),
(175, 'Radio', 'IAB9-24', '', 'IAB9', 0, 0),
(176, 'Roleplaying Games', 'IAB9-25', '', 'IAB9', 0, 0),
(177, 'Sci-Fi & Fantasy', 'IAB9-26', '', 'IAB9', 0, 0),
(178, 'Scrapbooking', 'IAB9-27', '', 'IAB9', 0, 0),
(179, 'Screenwriting', 'IAB9-28', '', 'IAB9', 0, 0),
(180, 'Stamps & Coins', 'IAB9-29', '', 'IAB9', 0, 0),
(181, 'Video & Computer Games', 'IAB9-30', '', 'IAB9', 0, 0),
(182, 'Woodworking', 'IAB9-31', '', 'IAB9', 0, 0),
(184, 'Home & Garden', 'IAB10', '', '0', 0, 0),
(185, 'Appliances', 'IAB10-1', '', 'IAB10', 0, 0),
(186, 'Entertaining', 'IAB10-2', '', 'IAB10', 0, 0),
(187, 'Environmental Safety', 'IAB10-3', '', 'IAB10', 0, 0),
(188, 'Gardening', 'IAB10-4', '', 'IAB10', 0, 0),
(189, 'Home Repair', 'IAB10-5', '', 'IAB10', 0, 0),
(190, 'Home Theater', 'IAB10-6', '', 'IAB10', 0, 0),
(191, 'Interior Decorating', 'IAB10-7', '', 'IAB10', 0, 0),
(192, 'Landscaping', 'IAB10-8', '', 'IAB10', 0, 0),
(193, 'Remodeling & Construction', 'IAB10-9', '', 'IAB10', 0, 0),
(194, 'Law, Gov\t & Politics', 'IAB11', '', '0', 0, 0),
(195, 'Immigration', 'IAB11-1', '', 'IAB11', 0, 0),
(196, 'Legal Issues', 'IAB11-2', '', 'IAB11', 0, 0),
(197, 'U.S. Government Resources', 'IAB11-3', '', 'IAB11', 0, 0),
(198, 'Politics', 'IAB11-4', '', 'IAB11', 0, 0),
(199, 'Commentary', 'IAB11-5', '', 'IAB11', 0, 0),
(200, 'News', 'IAB12', '', '0', 0, 0),
(201, 'International News', 'IAB12-1', '', 'IAB12', 0, 0),
(202, 'National News', 'IAB12-2', '', 'IAB12', 0, 0),
(203, 'Local News', 'IAB12-3', '', 'IAB12', 0, 0),
(204, 'Personal Finance', 'IAB13', '', '0', 0, 0),
(205, 'Beginning Investing', 'IAB13-1', '', 'IAB13', 0, 0),
(206, 'Credit/Debt & Loans', 'IAB13-2', '', 'IAB13', 0, 0),
(207, 'Financial News', 'IAB13-3', '', 'IAB13', 0, 0),
(208, 'Financial Planning', 'IAB13-4', '', 'IAB13', 0, 0),
(209, 'Hedge Fund', 'IAB13-5', '', 'IAB13', 0, 0),
(210, 'Insurance', 'IAB13-6', '', 'IAB13', 0, 0),
(211, 'Investing', 'IAB13-7', '', 'IAB13', 0, 0),
(212, 'Mutual Funds', 'IAB13-8', '', 'IAB13', 0, 0),
(213, 'Options', 'IAB13-9', '', 'IAB13', 0, 0),
(214, 'Retirement Planning', 'IAB13-10', '', 'IAB13', 0, 0),
(215, 'Stocks', 'IAB13-11', '', 'IAB13', 0, 0),
(216, 'Tax Planning', 'IAB13-12', '', 'IAB13', 0, 0),
(217, 'Society', 'IAB14', '', '0', 0, 0),
(218, 'Dating', 'IAB14-1', '', 'IAB14', 0, 0),
(219, 'Divorce Support', 'IAB14-2', '', 'IAB14', 0, 0),
(220, 'Gay Life', 'IAB14-3', '', 'IAB14', 0, 0),
(221, 'Marriage', 'IAB14-4', '', 'IAB14', 0, 0),
(222, 'Senior Living', 'IAB14-5', '', 'IAB14', 0, 0),
(223, 'Teens', 'IAB14-6', '', 'IAB14', 0, 0),
(224, 'Weddings', 'IAB14-7', '', 'IAB14', 0, 0),
(225, 'Ethnic Specific', 'IAB14-8', '', 'IAB14', 0, 0),
(226, 'Science', 'IAB15', '', '0', 0, 0),
(227, 'Astrology', 'IAB15-1', '', 'IAB15', 0, 0),
(228, 'Biology', 'IAB15-2', '', 'IAB15', 0, 0),
(229, 'Chemistry', 'IAB15-3', '', 'IAB15', 0, 0),
(230, 'Geology', 'IAB15-4', '', 'IAB15', 0, 0),
(231, 'Paranormal Phenomena', 'IAB15-5', '', 'IAB15', 0, 0),
(232, 'Physics', 'IAB15-6', '', 'IAB15', 0, 0),
(233, 'Space/Astronomy', 'IAB15-7', '', 'IAB15', 0, 0),
(234, 'Geography', 'IAB15-8', '', 'IAB15', 0, 0),
(235, 'Botany', 'IAB15-9', '', 'IAB15', 0, 0),
(236, 'Weather', 'IAB15-10', '', 'IAB15', 0, 0),
(237, 'Pets', 'IAB16', '', '0', 0, 0),
(238, 'Aquariums', 'IAB16-1', '', 'IAB16', 0, 0),
(239, 'Birds', 'IAB16-2', '', 'IAB16', 0, 0),
(240, 'Cats', 'IAB16-3', '', 'IAB16', 0, 0),
(241, 'Dogs', 'IAB16-4', '', 'IAB16', 0, 0),
(242, 'Large Animals', 'IAB16-5', '', 'IAB16', 0, 0),
(243, 'Reptiles', 'IAB16-6', '', 'IAB16', 0, 0),
(244, 'Veterinary Medicine', 'IAB16-7', '', 'IAB16', 0, 0),
(245, 'Sports', 'IAB17', '', '0', 0, 0),
(246, 'Auto Racing', 'IAB17-1', '', 'IAB17', 0, 0),
(247, 'Baseball', 'IAB17-2', '', 'IAB17', 0, 0),
(248, 'Bicycling', 'IAB17-3', '', 'IAB17', 0, 0),
(249, 'Bodybuilding', 'IAB17-4', '', 'IAB17', 0, 0),
(250, 'Boxing', 'IAB17-5', '', 'IAB17', 0, 0),
(251, 'Canoeing/Kayaking', 'IAB17-6', '', 'IAB17', 0, 0),
(252, 'Cheerleading', 'IAB17-7', '', 'IAB17', 0, 0),
(253, 'Climbing', 'IAB17-8', '', 'IAB17', 0, 0),
(254, 'Cricket', 'IAB17-9', '', 'IAB17', 0, 0),
(255, 'Figure Skating', 'IAB17-10', '', 'IAB17', 0, 0),
(256, 'Fly Fishing', 'IAB17-11', '', 'IAB17', 0, 0),
(257, 'Football', 'IAB17-12', '', 'IAB17', 0, 0),
(258, 'Freshwater Fishing', 'IAB17-13', '', 'IAB17', 0, 0),
(259, 'Game & Fish', 'IAB17-14', '', 'IAB17', 0, 0),
(260, 'Golf', 'IAB17-15', '', 'IAB17', 0, 0),
(261, 'Horse Racing', 'IAB17-16', '', 'IAB17', 0, 0),
(262, 'Horses', 'IAB17-17', '', 'IAB17', 0, 0),
(263, 'Hunting/Shooting', 'IAB17-18', '', 'IAB17', 0, 0),
(264, 'Inline Skating', 'IAB17-19', '', 'IAB17', 0, 0),
(265, 'Martial Arts', 'IAB17-20', '', 'IAB17', 0, 0),
(266, 'Mountain Biking', 'IAB17-21', '', 'IAB17', 0, 0),
(267, 'NASCAR Racing', 'IAB17-22', '', 'IAB17', 0, 0),
(268, 'Olympics', 'IAB17-23', '', 'IAB17', 0, 0),
(269, 'Paintball', 'IAB17-24', '', 'IAB17', 0, 0),
(270, 'Power & Motorcycles', 'IAB17-25', '', 'IAB17', 0, 0),
(271, 'Pro Basketball', 'IAB17-26', '', 'IAB17', 0, 0),
(272, 'Pro Ice Hockey', 'IAB17-27', '', 'IAB17', 0, 0),
(273, 'Rodeo', 'IAB17-28', '', 'IAB17', 0, 0),
(274, 'Rugby', 'IAB17-29', '', 'IAB17', 0, 0),
(275, 'Running/Jogging', 'IAB17-30', '', 'IAB17', 0, 0),
(276, 'Sailing', 'IAB17-31', '', 'IAB17', 0, 0),
(277, 'Saltwater Fishing', 'IAB17-32', '', 'IAB17', 0, 0),
(278, 'Scuba Diving', 'IAB17-33', '', 'IAB17', 0, 0),
(279, 'Skateboarding', 'IAB17-34', '', 'IAB17', 0, 0),
(280, 'Skiing', 'IAB17-35', '', 'IAB17', 0, 0),
(281, 'Snowboarding', 'IAB17-36', '', 'IAB17', 0, 0),
(282, 'Surfing/Bodyboarding', 'IAB17-37', '', 'IAB17', 0, 0),
(283, 'Swimming', 'IAB17-38', '', 'IAB17', 0, 0),
(284, 'Table Tennis/Ping-Pong', 'IAB17-39', '', 'IAB17', 0, 0),
(285, 'Tennis', 'IAB17-40', '', 'IAB17', 0, 0),
(286, 'Volleyball', 'IAB17-41', '', 'IAB17', 0, 0),
(287, 'Walking', 'IAB17-42', '', 'IAB17', 0, 0),
(288, 'Waterski/Wakeboard', 'IAB17-43', '', 'IAB17', 0, 0),
(289, 'World Soccer', 'IAB17-44', '', 'IAB17', 0, 0),
(290, 'Style & Fashion', 'IAB18', '', '0', 0, 0),
(291, 'Beauty', 'IAB18-1', '', 'IAB18', 0, 0),
(292, 'Body Art', 'IAB18-2', '', 'IAB18', 0, 0),
(293, 'Fashion', 'IAB18-3', '', 'IAB18', 0, 0),
(294, 'Jewelry', 'IAB18-4', '', 'IAB18', 0, 0),
(295, 'Clothing', 'IAB18-5', '', 'IAB18', 0, 0),
(296, 'Accessories', 'IAB18-6', '', 'IAB18', 0, 0),
(297, 'Technology & Computing', 'IAB19', '', '0', 0, 0),
(298, '3-D Graphics', 'IAB19-1', '', 'IAB19', 0, 0),
(299, 'Animation', 'IAB19-2', '', 'IAB19', 0, 0),
(300, 'Antivirus Software', 'IAB19-3', '', 'IAB19', 0, 0),
(301, 'C/C++', 'IAB19-4', '', 'IAB19', 0, 0),
(302, 'Cameras & Camcorders', 'IAB19-5', '', 'IAB19', 0, 0),
(303, 'Cell Phones', 'IAB19-6', '', 'IAB19', 0, 0),
(304, 'Computer Certification', 'IAB19-7', '', 'IAB19', 0, 0),
(305, 'Computer Networking', 'IAB19-8', '', 'IAB19', 0, 0),
(306, 'Computer Peripherals', 'IAB19-9', '', 'IAB19', 0, 0),
(307, 'Computer Reviews', 'IAB19-10', '', 'IAB19', 0, 0),
(308, 'Data Centers', 'IAB19-11', '', 'IAB19', 0, 0),
(309, 'Databases', 'IAB19-12', '', 'IAB19', 0, 0),
(310, 'Desktop Publishing', 'IAB19-13', '', 'IAB19', 0, 0),
(311, 'Desktop Video', 'IAB19-14', '', 'IAB19', 0, 0),
(312, 'Email', 'IAB19-15', '', 'IAB19', 0, 0),
(313, 'Graphics Software', 'IAB19-16', '', 'IAB19', 0, 0),
(314, 'Home Video/DVD', 'IAB19-17', '', 'IAB19', 0, 0),
(315, 'Internet Technology', 'IAB19-18', '', 'IAB19', 0, 0),
(316, 'Java', 'IAB19-19', '', 'IAB19', 0, 0),
(317, 'JavaScript', 'IAB19-20', '', 'IAB19', 0, 0),
(318, 'Mac Support', 'IAB19-21', '', 'IAB19', 0, 0),
(319, 'MP3/MIDI', 'IAB19-22', '', 'IAB19', 0, 0),
(320, 'Net Conferencing', 'IAB19-23', '', 'IAB19', 0, 0),
(321, 'Net for Beginners', 'IAB19-24', '', 'IAB19', 0, 0),
(322, 'Network Security', 'IAB19-25', '', 'IAB19', 0, 0),
(323, 'Palmtops/PDAs', 'IAB19-26', '', 'IAB19', 0, 0),
(324, 'PC Support', 'IAB19-27', '', 'IAB19', 0, 0),
(325, 'Portable', 'IAB19-28', '', 'IAB19', 0, 0),
(326, 'Entertainment', 'IAB19-29', '', 'IAB19', 0, 0),
(327, 'Shareware/Freeware', 'IAB19-30', '', 'IAB19', 0, 0),
(328, 'Unix', 'IAB19-31', '', 'IAB19', 0, 0),
(329, 'Visual Basic', 'IAB19-32', '', 'IAB19', 0, 0),
(330, 'Web Clip Art', 'IAB19-33', '', 'IAB19', 0, 0),
(331, 'Web Design/HTML', 'IAB19-34', '', 'IAB19', 0, 0),
(332, 'Web Search', 'IAB19-35', '', 'IAB19', 0, 0),
(333, 'Windows', 'IAB19-36', '', 'IAB19', 0, 0),
(334, 'Travel', 'IAB20', '', '0', 0, 0),
(335, 'Adventure Travel', 'IAB20-1', '', 'IAB20', 0, 0),
(336, 'Africa', 'IAB20-2', '', 'IAB20', 0, 0),
(337, 'Air Travel', 'IAB20-3', '', 'IAB20', 0, 0),
(338, 'Australia & New Zealand', 'IAB20-4', '', 'IAB20', 0, 0),
(339, 'Bed & Breakfasts', 'IAB20-5', '', 'IAB20', 0, 0),
(340, 'Budget Travel', 'IAB20-6', '', 'IAB20', 0, 0),
(341, 'Business Travel', 'IAB20-7', '', 'IAB20', 0, 0),
(342, 'By US Locale', 'IAB20-8', '', 'IAB20', 0, 0),
(343, 'Camping', 'IAB20-9', '', 'IAB20', 0, 0),
(344, 'Canada', 'IAB20-10', '', 'IAB20', 0, 0),
(345, 'Caribbean', 'IAB20-11', '', 'IAB20', 0, 0),
(346, 'Cruises', 'IAB20-12', '', 'IAB20', 0, 0),
(347, 'Eastern Europe', 'IAB20-13', '', 'IAB20', 0, 0),
(348, 'Europe', 'IAB20-14', '', 'IAB20', 0, 0),
(349, 'France', 'IAB20-15', '', 'IAB20', 0, 0),
(350, 'Greece', 'IAB20-16', '', 'IAB20', 0, 0),
(351, 'Honeymoons/Getaways', 'IAB20-17', '', 'IAB20', 0, 0),
(352, 'Hotels', 'IAB20-18', '', 'IAB20', 0, 0),
(353, 'Italy', 'IAB20-19', '', 'IAB20', 0, 0),
(354, 'Japan', 'IAB20-20', '', 'IAB20', 0, 0),
(355, 'Mexico & Central America', 'IAB20-21', '', 'IAB20', 0, 0),
(356, 'National Parks', 'IAB20-22', '', 'IAB20', 0, 0),
(357, 'South America', 'IAB20-23', '', 'IAB20', 0, 0),
(358, 'Spas', 'IAB20-24', '', 'IAB20', 0, 0),
(359, 'Theme Parks', 'IAB20-25', '', 'IAB20', 0, 0),
(360, 'Traveling with Kids', 'IAB20-26', '', 'IAB20', 0, 0),
(361, 'United Kingdom', 'IAB20-27', '', 'IAB20', 0, 0),
(362, 'Real Estate', 'IAB21', '', '0', 0, 0),
(363, 'Apartments', 'IAB21-1', '', 'IAB21', 0, 0),
(364, 'Architects', 'IAB21-2', '', 'IAB21', 0, 0),
(365, 'Buying/Selling Homes', 'IAB21-3', '', 'IAB21', 0, 0),
(366, 'Shopping', 'IAB22', '', '0', 0, 0),
(367, 'Contests & Freebies', 'IAB22-1', '', 'IAB22', 0, 0),
(368, 'Couponing', 'IAB22-2', '', 'IAB22', 0, 0),
(369, 'Comparison', 'IAB22-3', '', 'IAB22', 0, 0),
(370, 'Engines', 'IAB22-4', '', 'IAB22', 0, 0),
(371, 'Religion & Spirituality', 'IAB23', '', '0', 0, 0),
(372, 'Alternative Religions', 'IAB23-1', '', 'IAB23', 0, 0),
(373, 'Atheism/Agnosticism', 'IAB23-2', '', 'IAB23', 0, 0),
(374, 'Buddhism', 'IAB23-3', '', 'IAB23', 0, 0),
(375, 'Catholicism', 'IAB23-4', '', 'IAB23', 0, 0),
(376, 'Christianity', 'IAB23-5', '', 'IAB23', 0, 0),
(377, 'Hinduism', 'IAB23-6', '', 'IAB23', 0, 0),
(378, 'Islam', 'IAB23-7', '', 'IAB23', 0, 0),
(379, 'Judaism', 'IAB23-8', '', 'IAB23', 0, 0),
(380, 'Latter-Day Saints', 'IAB23-9', '', 'IAB23', 0, 0),
(381, 'Pagan/Wiccan', 'IAB23-10', '', 'IAB23', 0, 0),
(382, 'Uncategorized', 'IAB24', '', '0', 0, 0),
(383, 'Non-Standard Content', 'IAB25', '', '0', 0, 0),
(384, 'Unmoderated UGC', 'IAB25-1', '', 'IAB25', 0, 0),
(385, 'Extreme Graphic/Explicit Violence', 'IAB25-2', '', 'IAB25', 0, 0),
(386, 'Pornography', 'IAB25-3', '', 'IAB25', 0, 0),
(387, 'Profane Content', 'IAB25-4', '', 'IAB25', 0, 0),
(388, 'Hate Content', 'IAB25-5', '', 'IAB25', 0, 0),
(389, 'Under Construction', 'IAB25-6', '', 'IAB25', 0, 0),
(390, 'Incentivized', 'IAB25-7', '', 'IAB25', 0, 0),
(391, 'Illegal Content', 'IAB26', '', '0', 0, 0),
(392, 'Illegal Content', 'IAB26-1', '', 'IAB26', 0, 0),
(393, 'Warez', 'IAB26-2', '', 'IAB26', 0, 0),
(394, 'Spyware/Malware', 'IAB26-3', '', 'IAB26', 0, 0),
(395, 'CopyrightInfringement', 'IAB26-4', '', 'IAB26', 0, 0);




-- Table structure for table "rv_profile"

CREATE TABLE rv_profile (
  profileid SERIAL PRIMARY KEY,  -- Using SERIAL for auto-increment, which automatically handles sequence
  name VARCHAR(255) NOT NULL
);

-- PostgreSQL automatically creates a sequence for the SERIAL column. There's no need for separate sequence creation or setting defaults manually.

-- If you want to manually set the starting value for the sequence, you can do it with:
-- ALTER SEQUENCE rv_profile_profileid_seq RESTART WITH 25;
